@@ -18,6 +18,7 @@ import re  # noqa: F401
 import six
 import typing
 from enum import Enum
+from ask_sdk_model.interfaces.geolocation.geolocation_common_state import GeolocationCommonState
 
 
 if typing.TYPE_CHECKING:
@@ -30,8 +31,10 @@ if typing.TYPE_CHECKING:
     from ask_sdk_model.interfaces.geolocation.location_services import LocationServices as LocationServices_c8dfc485
 
 
-class GeolocationState(object):
+class GeolocationState(GeolocationCommonState):
     """
+    The geolocation object used in the Context of API
+
 
     :param timestamp: Specifies the time when the geolocation data was last collected on the device.
     :type timestamp: (optional) str
@@ -68,7 +71,7 @@ class GeolocationState(object):
 
     def __init__(self, timestamp=None, coordinate=None, altitude=None, heading=None, speed=None, location_services=None):
         # type: (Optional[str], Optional[Coordinate_c6912a2], Optional[Altitude_328a6962], Optional[Heading_bf10e3ca], Optional[Speed_22d2d794], Optional[LocationServices_c8dfc485]) -> None
-        """
+        """The geolocation object used in the Context of API
 
         :param timestamp: Specifies the time when the geolocation data was last collected on the device.
         :type timestamp: (optional) str
@@ -85,11 +88,7 @@ class GeolocationState(object):
         """
         self.__discriminator_value = None  # type: str
 
-        self.timestamp = timestamp
-        self.coordinate = coordinate
-        self.altitude = altitude
-        self.heading = heading
-        self.speed = speed
+        super(GeolocationState, self).__init__(timestamp=timestamp, coordinate=coordinate, altitude=altitude, heading=heading, speed=speed)
         self.location_services = location_services
 
     def to_dict(self):
