@@ -21,7 +21,7 @@ from enum import Enum
 
 
 if typing.TYPE_CHECKING:
-    from typing import Dict, List, Optional, Union
+    from typing import Dict, List, Optional, Union, Any
     from datetime import datetime
 
 
@@ -35,7 +35,7 @@ class ListItemState(Enum):
     completed = "completed"
 
     def to_dict(self):
-        # type: () -> Dict[str, object]
+        # type: () -> Dict[str, Any]
         """Returns the model properties as a dict"""
         result = {self.name: self.value}
         return result
@@ -51,7 +51,7 @@ class ListItemState(Enum):
         return self.to_str()
 
     def __eq__(self, other):
-        # type: (object) -> bool
+        # type: (Any) -> bool
         """Returns true if both objects are equal"""
         if not isinstance(other, ListItemState):
             return False
@@ -59,6 +59,6 @@ class ListItemState(Enum):
         return self.__dict__ == other.__dict__
 
     def __ne__(self, other):
-        # type: (object) -> bool
+        # type: (Any) -> bool
         """Returns true if both objects are not equal"""
         return not self == other
